<?php

# Copyright (C) 2002, 2003 Mathieu Roy <yeupou--gnu.org>
# Copyright (C) 2005 Sylvain Beucler
# Copyright (C) 2015, 2016, 2017 Karl Berry
# Copyright (C) 2013, 2017, 2023 Ineiev <ineiev@gnu.org>
# Copyright (C) 2022 Bob Proulx
#
# This file is part of Savane.
#
# Savane is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# Savane is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

print '<meta name="Author" content="'
 . "Copyright 2023 Free Software Foundation, Inc.\n"
 . _("Verbatim copying and distribution of this entire article\n"
     . "is permitted in any medium, provided this notice is preserved.")
 . "\" />\n<meta name=\"description\" content=\""
 . _("Savannah is a central point for development, distribution\n"
     . "and maintenance of free software, both GNU and non-GNU.") . "\" />\n";
?>
